@@ -1,7 +1,7 @@
 use crate::command::{self, CommandType, Invoke, PathArgs, WorkingDir};
 use anyhow::Result;
 use indexmap::IndexMap;
-use log::warn;
+//use log::warn;
 use serde::{de, de::Deserializer, Deserialize};
 use std::{
     collections::HashMap,
@@ -188,7 +188,7 @@ where
         {
             if value < 0 || value > std::u8::MAX as i64 {
                 return Err(de::Error::invalid_type(
-                    de::Unexpected::Signed(value as i64),
+                    de::Unexpected::Signed(value),
                     &"an integer from 0-255",
                 ));
             }
@@ -237,7 +237,7 @@ where
         {
             if value > std::u8::MAX as u64 {
                 return Err(de::Error::invalid_type(
-                    de::Unexpected::Unsigned(value as u64),
+                    de::Unexpected::Unsigned(value),
                     &"an integer from 0-255",
                 ));
             }
@@ -451,12 +451,12 @@ impl CommandConfig {
         // This translates the old config options into their equivalent new
         // options.
         if run_mode.is_some() || chdir.is_some() {
-            let options = match (run_mode, chdir) {
-                (Some(_), None) => "run_mode",
-                (None, Some(_)) => "chdir",
-                _ => "run_mode and chdir",
-            };
-            //warn!("The {name} command is using deprecated config options: {options}");
+            // let options = match (run_mode, chdir) {
+            //     (Some(_), None) => "run_mode",
+            //     (None, Some(_)) => "chdir",
+            //     _ => "run_mode and chdir",
+            // };
+            // warn!("The {name} command is using deprecated config options: {options}");
 
             match (run_mode, chdir) {
                 (Some(OldRunMode::Files) | None, Some(false) | None) => {
@@ -613,10 +613,10 @@ mod tests {
             "#,
         );
         if let Some(run_mode) = run_mode {
-            toml_text.push_str(&format!("run_mode = \"{}\"\n", run_mode));
+            toml_text.push_str(&format!("run_mode = \"{run_mode}\"\n"));
         }
         if let Some(chdir) = chdir {
-            toml_text.push_str(&format!("chdir = {}\n", chdir));
+            toml_text.push_str(&format!("chdir = {chdir}\n"));
         }
 
         let config: Config = toml::from_str(&toml_text)?;
